@@ -43,17 +43,17 @@ from dipdup.utils import snake_to_pascal
 from dipdup.utils import touch
 from dipdup.utils import write
 
-DEFAULT_DOCKER_ENV_FILE_CONTENT = dict(
-    POSTGRES_USER="dipdup",
-    POSTGRES_DB="dipdup",
-    POSTGRES_PASSWORD="changeme",
-    HASURA_GRAPHQL_DATABASE_URL="postgres://dipdup:changeme@db:5432/dipdup",
-    HASURA_GRAPHQL_ENABLE_CONSOLE="true",
-    HASURA_GRAPHQL_ADMIN_INTERNAL_ERRORS="true",
-    HASURA_GRAPHQL_ENABLED_LOG_TYPES="startup, http-log, webhook-log, websocket-log, query-log",
-    HASURA_GRAPHQL_ADMIN_SECRET="changeme",
-    HASURA_GRAPHQL_UNAUTHORIZED_ROLE="user",
-)
+DEFAULT_DOCKER_ENV_FILE_CONTENT = {
+    'POSTGRES_USER': 'dipdup',
+    'POSTGRES_DB': 'dipdup',
+    'POSTGRES_PASSWORD': 'changeme',
+    'HASURA_GRAPHQL_DATABASE_URL': 'postgres://dipdup:changeme@db:5432/dipdup',
+    'HASURA_GRAPHQL_ENABLE_CONSOLE': 'true',
+    'HASURA_GRAPHQL_ADMIN_INTERNAL_ERRORS': 'true',
+    'HASURA_GRAPHQL_ENABLED_LOG_TYPES': 'startup, http-log, webhook-log, websocket-log, query-log',
+    'HASURA_GRAPHQL_ADMIN_SECRET': 'changeme',
+    'HASURA_GRAPHQL_UNAUTHORIZED_ROLE': 'user',
+}
 DEFAULT_DOCKER_IMAGE = 'dipdup/dipdup'
 DEFAULT_DOCKER_TAG = __version__
 DEFAULT_DOCKER_ENV_FILE = 'dipdup.env'
@@ -66,6 +66,8 @@ def preprocess_storage_jsonschema(schema: Dict[str, Any]) -> Dict[str, Any]:
     We resolve bigmaps from diffs so no need to include int in type signature."""
     if not isinstance(schema, dict):
         return schema
+    if 'oneOf' in schema:
+        schema['oneOf'] = [preprocess_storage_jsonschema(sub_schema) for sub_schema in schema['oneOf']]
     if 'properties' in schema:
         return {
             **schema,
@@ -104,14 +106,15 @@ class DipDupCodeGenerator:
         self._datasources = datasources
         self._schemas: Dict[TzktDatasourceConfig, Dict[str, Dict[str, Any]]] = {}
 
-    async def init(self, overwrite_types: bool = False) -> None:
+    async def init(self, overwrite_types: bool = False, keep_schemas: bool = False) -> None:
         self._logger.info('Initializing project')
         await self.create_package()
         await self.fetch_schemas()
         await self.generate_types(overwrite_types)
         await self.generate_hooks()
         await self.generate_handlers()
-        await self.cleanup()
+        if not keep_schemas:
+            await self.cleanup()
         await self.verify_package()
 
     async def docker_init(self, image: str, tag: str, env_file: str) -> None:
