@@ -3,41 +3,55 @@ import os
 import sys
 import time
 from collections import deque
-from contextlib import contextmanager, suppress
-from os.path import exists, join
+from contextlib import contextmanager
+from contextlib import suppress
+from os.path import exists
+from os.path import join
 from pprint import pformat
-from typing import Any, Dict, Iterator, NoReturn, Optional, Tuple, Union, cast
+from typing import Any
+from typing import Dict
+from typing import Iterator
+from typing import Optional
+from typing import Tuple
+from typing import Union
+from typing import cast
 
 import sqlparse  # type: ignore
+from tortoise import Tortoise
 from tortoise.exceptions import OperationalError
 from tortoise.transactions import get_connection
 
-from dipdup.config import (
-    BigMapIndexConfig,
-    ContractConfig,
-    DipDupConfig,
-    HandlerConfig,
-    HeadIndexConfig,
-    HookConfig,
-    IndexTemplateConfig,
-    OperationIndexConfig,
-    PostgresDatabaseConfig,
-    ResolvedIndexConfigT,
-    TzktDatasourceConfig,
-)
+from dipdup.config import BigMapIndexConfig
+from dipdup.config import ContractConfig
+from dipdup.config import DipDupConfig
+from dipdup.config import HandlerConfig
+from dipdup.config import HeadIndexConfig
+from dipdup.config import HookConfig
+from dipdup.config import IndexTemplateConfig
+from dipdup.config import OperationIndexConfig
+from dipdup.config import PostgresDatabaseConfig
+from dipdup.config import ResolvedIndexConfigT
+from dipdup.config import TzktDatasourceConfig
 from dipdup.datasources.datasource import Datasource
 from dipdup.datasources.tzkt.datasource import TzktDatasource
-from dipdup.exceptions import (
-    CallbackError,
-    CallbackTypeError,
-    ConfigurationError,
-    ContractAlreadyExistsError,
-    IndexAlreadyExistsError,
-    InitializationRequiredError,
-    ReindexingRequiredError,
-)
-from dipdup.models import Contract, ReindexingReason, Schema
-from dipdup.utils import FormattedLogger, iter_files
+from dipdup.enums import ReindexingAction
+from dipdup.enums import ReindexingReasonC
+from dipdup.enums import reason_to_reasonc
+from dipdup.enums import reasonc_to_reason
+from dipdup.exceptions import CallbackError
+from dipdup.exceptions import CallbackTypeError
+from dipdup.exceptions import ConfigurationError
+from dipdup.exceptions import ContractAlreadyExistsError
+from dipdup.exceptions import IndexAlreadyExistsError
+from dipdup.exceptions import InitializationRequiredError
+from dipdup.exceptions import ReindexingRequiredError
+from dipdup.models import Contract
+from dipdup.models import Index
+from dipdup.models import ReindexingReason
+from dipdup.models import Schema
+from dipdup.utils import FormattedLogger
+from dipdup.utils import iter_files
+from dipdup.utils.database import wipe_schema
 
 pending_indexes = deque()  # type: ignore
 
@@ -88,22 +102,45 @@ class DipDupContext:
             sys.argv.remove('--reindex')
         os.execl(sys.executable, sys.executable, *sys.argv)
 
-    async def reindex(self, reason: Optional[Union[str, ReindexingReason]] = None, **context) -> NoReturn:
+    async def reindex(self, reason: Optional[Union[str, ReindexingReason, ReindexingReasonC]] = None, **context) -> None:
         """Drop all tables or whole database and restart with the same CLI arguments"""
         if not reason:
-            reason = ReindexingReason.MANUAL
+            reason = ReindexingReasonC.manual
         elif isinstance(reason, str):
             context['message'] = reason
-            reason = ReindexingReason.MANUAL
+            reason = ReindexingReasonC.manual
+        elif isinstance(reason, ReindexingReason):
+            reason = reason_to_reasonc[reason]
+        else:
+            raise NotImplementedError
 
-        reason_str = reason.value + (f' ({context["message"]})' if "message" in context else '')
-        self.logger.warning('Reindexing initialized, reason: %s', reason_str)
+        action = self.config.advanced.reindex.get(reason, ReindexingAction.exception)
+        self.logger.warning('Reindexing initialized, reason: %s, action: %s', reason.value, action.value)
 
-        schema = await Schema.filter().get()
-        if not schema.reindex:
-            schema.reindex = reason
-            await schema.save()
-        raise ReindexingRequiredError(schema.reindex, context)
+        if action == ReindexingAction.ignore:
+            if reason == ReindexingReasonC.schema_modified:
+                await Schema.filter(name=self.config.schema_name).update(hash='')
+            elif reason == ReindexingReasonC.config_modified:
+                await Index.filter().update(config_hash='')
+            return
+
+        elif action == ReindexingAction.exception:
+            schema = await Schema.filter(name=self.config.schema_name).get()
+            if not schema.reindex:
+                schema.reindex = reasonc_to_reason[reason]
+                await schema.save()
+            raise ReindexingRequiredError(schema.reindex, context)
+
+        elif action == ReindexingAction.wipe:
+            conn = get_connection(None)
+            if isinstance(self.config.database, PostgresDatabaseConfig):
+                await wipe_schema(conn, self.config.database.schema_name, self.config.database.immune_tables)
+            else:
+                await Tortoise._drop_databases()
+            await self.restart()
+
+        else:
+            raise NotImplementedError
 
     async def add_contract(self, name: str, address: str, typename: Optional[str] = None) -> None:
         self.logger.info('Creating contract `%s` with typename `%s`', name, typename)
@@ -124,7 +161,8 @@ class DipDupContext:
                 typename=contract_config.typename,
             ).save()
 
-    async def add_index(self, name: str, template: str, values: Dict[str, Any]) -> None:
+    # TODO: Option to override first_level/last_level?
+    async def add_index(self, name: str, template: str, values: Dict[str, Any], state: Optional[Index] = None) -> None:
         self.logger.info('Creating index `%s` from template `%s`', name, template)
         if name in self.config.indexes:
             raise IndexAlreadyExistsError(self, name)
@@ -135,10 +173,12 @@ class DipDupContext:
         )
         self.config.initialize()
 
-        await self._spawn_index(name)
+        await self.spawn_index(name, state)
 
-    async def _spawn_index(self, name: str) -> None:
-        from dipdup.index import BigMapIndex, HeadIndex, OperationIndex
+    async def spawn_index(self, name: str, state: Optional[Index] = None) -> None:
+        from dipdup.index import BigMapIndex
+        from dipdup.index import HeadIndex
+        from dipdup.index import OperationIndex
 
         index_config = cast(ResolvedIndexConfigT, self.config.get_index(name))
         index: Union[OperationIndex, BigMapIndex, HeadIndex]
@@ -160,8 +200,9 @@ class DipDupContext:
         await datasource.add_index(index_config)
         for handler_config in index_config.handlers:
             self.callbacks.register_handler(handler_config)
-        await index.initialize_state()
+        await index.initialize_state(state)
 
+        # NOTE: IndexDispatcher will handle further initialization when it's time
         pending_indexes.append(index)
 
 
@@ -318,9 +359,11 @@ class CallbackManager:
             start = time.perf_counter()
             yield
             diff = time.perf_counter() - start
-            level = self._logger.info if diff > 1 else self._logger.debug
+            level = self._logger.warning if diff > 1 else self._logger.debug
             level('`%s` %s callback executed in %s seconds', name, kind, diff)
         except Exception as e:
+            if isinstance(e, ReindexingRequiredError):
+                raise
             raise CallbackError(kind, name) from e
 
     @classmethod
