@@ -274,21 +274,54 @@ class HasuraGateway(HTTPGateway):
                 if isinstance(field, fields.relational.ForeignKeyFieldInstance):
                     if not isinstance(field.related_name, str):
                         raise HasuraError(f'`related_name` of `{field}` must be set')
+
                     related_table_name = model_tables[field.model_name]
+                    field_name = field.model_field_name
                     metadata_tables[table_name]['object_relationships'].append(
                         self._format_object_relationship(
-                            name=field.model_field_name,
-                            column=field.model_field_name + '_id',
+                            name=field_name,
+                            column=field_name + '_id',
                         )
                     )
                     metadata_tables[related_table_name]['array_relationships'].append(
                         self._format_array_relationship(
                             related_name=field.related_name,
                             table=table_name,
-                            column=field.model_field_name + '_id',
+                            column=field_name + '_id',
                         )
                     )
 
+                elif isinstance(field, fields.relational.ManyToManyFieldInstance):
+                    if not isinstance(field.related_name, str):
+                        raise HasuraError(f'`related_name` of `{field}` must be set')
+
+                    related_table_name = model_tables[field.model_name]
+                    junction_table_name = field.through
+
+                    metadata_tables[junction_table_name] = self._format_table(junction_table_name)
+                    metadata_tables[junction_table_name]['object_relationships'].append(
+                        self._format_object_relationship(
+                            name=related_table_name,
+                            column=related_table_name + '_id',
+                        )
+                    )
+                    metadata_tables[junction_table_name]['object_relationships'].append(
+                        self._format_object_relationship(
+                            name=table_name,
+                            column=table_name + '_id',
+                        )
+                    )
+                    metadata_tables[related_table_name]['array_relationships'].append(
+                        self._format_array_relationship(
+                            related_name=f'{related_table_name}_{field.related_name}',
+                            table=junction_table_name,
+                            column=related_table_name + '_id',
+                        )
+                    )
+
+                else:
+                    pass
+
         return list(metadata_tables.values())
 
     async def _generate_query_collections_metadata(self) -> List[Dict[str, Any]]:
@@ -307,7 +340,7 @@ class HasuraGateway(HTTPGateway):
             queries.append(self._format_rest_query(table_name, table_name, filter, fields))
 
         for query_name, query in self._iterate_graphql_queries():
-            queries.append(dict(name=query_name, query=query))
+            queries.append({'name': query_name, 'query': query})
 
         return queries
 
