@@ -6,7 +6,10 @@ import platform
 from abc import ABC
 from contextlib import suppress
 from http import HTTPStatus
-from typing import Mapping, Optional, Tuple, cast
+from typing import Mapping
+from typing import Optional
+from typing import Tuple
+from typing import cast
 
 import aiohttp
 from aiolimiter import AsyncLimiter
@@ -132,19 +135,19 @@ class _HTTPGateway:
                 self._logger.info('Waiting %s seconds before retry', ratelimit_sleep or retry_sleep)
                 await asyncio.sleep(ratelimit_sleep or retry_sleep)
                 attempt += 1
-                multiplier = 1 if ratelimit_sleep is None else self._config.retry_multiplier or 1
+                multiplier = 1 if ratelimit_sleep else self._config.retry_multiplier or 1
                 retry_sleep *= multiplier
 
     async def _request(self, method: str, url: str, weight: int = 1, **kwargs):
         """Wrapped aiohttp call with preconfigured headers and ratelimiting"""
-        headers = {
-            **kwargs.pop('headers', {}),
-            'User-Agent': self.user_agent,
-        }
         if not url.startswith(self._url):
             url = self._url + '/' + url.lstrip('/')
+
+        headers = kwargs.pop('headers', {})
+        headers['User-Agent'] = self.user_agent
+
         params = kwargs.get('params', {})
-        params_string = '&'.join([f'{k}={v}' for k, v in params.items()])
+        params_string = '&'.join(f'{k}={v}' for k, v in params.items())
         request_string = f'{url}?{params_string}'.rstrip('?')
         self._logger.debug('Calling `%s`', request_string)
 
@@ -172,10 +175,9 @@ class _HTTPGateway:
             except KeyError:
                 response = await self._retry_request(method, url, weight, **kwargs)
                 self._cache[key] = response
-                return response
+                return response  # noqa: R504
         else:
-            response = await self._retry_request(method, url, weight, **kwargs)
-            return response
+            return await self._retry_request(method, url, weight, **kwargs)
 
     async def close_session(self) -> None:
         """Close aiohttp session"""
