@@ -1,19 +1,36 @@
 import asyncio
 import importlib
 import logging
+import os
 import pkgutil
 import time
 import types
 from collections import defaultdict
 from contextlib import asynccontextmanager
-from functools import partial, reduce
+from functools import partial
+from functools import reduce
 from logging import Logger
-from os import listdir, makedirs
-from os.path import dirname, exists, getsize, join
-from typing import Any, Callable, DefaultDict, Dict, Iterator, List, Optional, Sequence, TextIO, TypeVar
+from os import listdir
+from os import makedirs
+from os.path import dirname
+from os.path import exists
+from os.path import getsize
+from os.path import join
+from typing import Any
+from typing import Callable
+from typing import DefaultDict
+from typing import Dict
+from typing import Iterator
+from typing import List
+from typing import Optional
+from typing import Sequence
+from typing import TextIO
+from typing import TypeVar
+from unittest import skip
 
 import humps  # type: ignore
-from genericpath import isdir, isfile
+from genericpath import isdir
+from genericpath import isfile
 
 from dipdup.exceptions import HandlerImportError
 
@@ -152,3 +169,9 @@ def remove_prefix(text: str, prefix: str) -> str:
     if text.startswith(prefix):
         text = text[len(prefix) :]
     return text.strip('_')
+
+
+def skip_ci(fn):
+    if os.environ.get('CI'):
+        return skip('CI environment, skipping')(fn)
+    return fn
